@@ -18,7 +18,6 @@ import logging
 import random
 import os.path
 import sys
-import webbrowser
 import six
 
 from requests_toolbelt import MultipartEncoder
@@ -128,11 +127,8 @@ class FlickrAccessToken(object):
         self.user_nsid = user_nsid
 
     def __str__(self):
-        return six.text_type(self).encode('utf-8')
-
-    def __unicode__(self):
-        return 'FlickrAccessToken(token=%s, fullname=%s, username=%s, user_nsid=%s)' % (
-            self.token, self.fullname, self.username, self.user_nsid)
+        fmt = 'FlickrAccessToken(token=%s, fullname=%s, username=%s, user_nsid=%s)'
+        return six.text_type(fmt % (self.token, self.fullname, self.username, self.user_nsid))
 
     def __repr__(self):
         return str(self)
@@ -155,7 +151,7 @@ class OAuthFlickrInterface(object):
     AUTHORIZE_URL = "https://www.flickr.com/services/oauth/authorize"
     ACCESS_TOKEN_URL = "https://www.flickr.com/services/oauth/access_token"
 
-    def __init__(self, api_key, api_secret, oauth_token=None):
+    def __init__(self, api_key, api_secret, oauth_token=None, default_timeout=None):
         self.log = logging.getLogger('%s.%s' % (self.__class__.__module__, self.__class__.__name__))
 
         assert isinstance(api_key, six.text_type), 'api_key must be unicode string'
@@ -171,6 +167,7 @@ class OAuthFlickrInterface(object):
         self.oauth_token = oauth_token
         self.auth_http_server = None
         self.requested_permissions = None
+        self.default_timeout = default_timeout
 
     @property
     def key(self):
@@ -241,15 +238,19 @@ class OAuthFlickrInterface(object):
 
         return os.path.expanduser('~/.flickrapi/cache')
 
-    def do_request(self, url, params=None):
+    def do_request(self, url, params=None, timeout=None):
         """Performs the HTTP request, signed with OAuth.
 
+        :param timeout: optional request timeout, in seconds.
+        :type timeout: float
+
         @return: the response content
         """
 
         req = self.session.post(url,
-                            data=params,
-                            auth=self.oauth)
+                                data=params,
+                                auth=self.oauth,
+                                timeout=timeout or self.default_timeout)
 
         # check the response headers / status code.
         if req.status_code != 200:
@@ -262,9 +263,12 @@ class OAuthFlickrInterface(object):
 
         return req.content
 
-    def do_upload(self, filename, url, params=None, fileobj=None):
+    def do_upload(self, filename, url, params=None, fileobj=None, timeout=None):
         """Performs a file upload to the given URL with the given parameters, signed with OAuth.
 
+        :param timeout: optional request timeout, in seconds.
+        :type timeout: float
+
         @return: the response content
         """
 
@@ -291,7 +295,7 @@ class OAuthFlickrInterface(object):
         auth = {'Authorization': headers.get('Authorization'),
                 'Content-Type': m.content_type}
         self.log.debug('POST %s', auth)
-        req = self.session.post(url, data=m, headers=auth)
+        req = self.session.post(url, data=m, headers=auth, timeout=timeout or self.default_timeout)
 
         # check the response headers / status code.
         if req.status_code != 200:
@@ -324,13 +328,15 @@ class OAuthFlickrInterface(object):
     def _start_http_server(self):
         """Starts the HTTP server, if it wasn't started already."""
 
-        if self.auth_http_server is not None: return
+        if self.auth_http_server is not None:
+            return
         self.auth_http_server = OAuthTokenHTTPServer()
 
     def _stop_http_server(self):
         """Stops the HTTP server, if one was started."""
 
-        if self.auth_http_server is None: return
+        if self.auth_http_server is None:
+            return
         self.auth_http_server = None
 
     def get_request_token(self, oauth_callback=None):
@@ -397,6 +403,7 @@ class OAuthFlickrInterface(object):
 
         Updates the given request_token by setting the OAuth verifier.
         """
+        import webbrowser
 
         # The HTTP server may have been started already, but we're not sure. Just start
         # it if it needs to be started.
@@ -440,7 +447,7 @@ class OAuthFlickrInterface(object):
         Only use this in unit tests.
         """
 
-        auth_url = self.auth_url(perms=perms)
+        auth_url = self.auth_url(perms=perms)  # noqa: F841
         # Normally we would direct the user to this URL. Now we don't.
         self.verifier = u'test'
 
